##  Using Tags as Views in Reports
Tags enable more detailed and customized reporting. You can generate insights based on specific tags to identify trends, gaps, and opportunities within your IT landscape. Simply select the needed tag group from the View drop-down list in reports. Note that only single-select tag groups are available for use as views in reports.
![Using Tags as Views in Reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2758103b7a4410148afdc0c834c4b558_LowRes.gif)
Using Tags as Views in Reports
